@@ -1,7 +1,10 @@
 # -*- coding: utf-8 -*-
 
 from django.db import models
+from django.db.models.signals import post_save
+from django.dispatch import receiver
 from mptt.models import MPTTModel, TreeForeignKey
+from repositories.plataforma.models import Index
 
 
 class Produto(models.Model):
@@ -67,6 +70,16 @@ class Produto(models.Model):
             return self.cache_url
         return None
 
+    def atualizar_dados_elasticsearch(self):
+        """Cria um faz update de uma row no ProdutoIndex"""
+        if self.removido:
+            self.remover_produto_elasticsearch()
+        else:
+            filtro = dict(produto_id=self.id, conta_id=self.conta_id)
+            atualizados = Index.objects.filter(**filtro).update(status=2, status_alt=2)
+            if not atualizados:
+                Index.objects.create(status=2, status_alt=2, **filtro)
+
 
 class Categoria(MPTTModel):
     id = models.AutoField(db_column="categoria_id", primary_key=True)
@@ -167,4 +180,10 @@ class ProdutoEstoque(models.Model):
             quantidade = pedido_item.quantidade
 
         self.quantidade = self.quantidade - quantidade
-        self.save()
\ No newline at end of file
+        self.save()
+
+
+@receiver(post_save, sender=ProdutoEstoque)
+def produto_estoque_post_save(sender, instance, created, raw, **kwargs):
+    if not created:
+        instance.produto.atualizar_dados_elasticsearch()
