@@ -205,6 +205,29 @@ class Tema(models.Model):
         db_table = u"faturamento\".\"tb_tema"
 
 
+class Banner(models.Model):
+
+    id = models.AutoField(db_column="banner_id", primary_key=True)
+    nome = models.TextField(db_column="banner_nome")
+    poweredby = models.TextField(db_column="banner_poweredby")
+    chamada = models.TextField(db_column="banner_chamada")
+    valor = models.DecimalField(db_column="banner_valor")
+
+    url_thumbnail = models.TextField(db_column="banner_url_thumbnail")
+    url_screenshots = models.TextField(db_column="banner_url_screenshots")
+    url_download = models.TextField(db_column="banner_url_download")
+    url_lojamodelo = models.TextField(db_column="banner_url_lojamodelo")
+
+    data_criacao = models.DateTimeField(db_column="banner_data_criacao", default=0)
+    data_modificacao = models.DateTimeField(db_column="banner_data_modificacao", auto_now=True)
+
+    colecao = models.ForeignKey("Colecao", db_column="colecao_id")
+
+    class Meta:
+        app_label = 'faturamento'
+        db_table = u"faturamento\".\"tb_banner"
+
+
 class Consumo(models.Model):
 
     id = models.AutoField(db_column="consumo_id", primary_key=True)
